Functions
- clean_
num - Get the clean number.
- format_
to - Formats the number and writes the result to out.
- map_num
- Takes a raw number string and applies the format.
- parse_
fmt - Parse the number according to the exact format.
- parse_
sym - Parse the number only using the symbols for translation. Takes digits and some specials and ignores the rest.
- unmap_
num - Unmap the formatted string back to a format that
f64::parse()can understand.